package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.NetworkMap;

/**
 * 网络拓扑Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface NetworkMapMapper 
{
    /**
     * 查询网络拓扑
     * 
     * @param id 网络拓扑主键
     * @return 网络拓扑
     */
    public NetworkMap selectNetworkMapById(Integer id);

    /**
     * 查询网络拓扑列表
     * 
     * @param networkMap 网络拓扑
     * @return 网络拓扑集合
     */
    public List<NetworkMap> selectNetworkMapList(NetworkMap networkMap);

    /**
     * 新增网络拓扑
     * 
     * @param networkMap 网络拓扑
     * @return 结果
     */
    public int insertNetworkMap(NetworkMap networkMap);

    /**
     * 修改网络拓扑
     * 
     * @param networkMap 网络拓扑
     * @return 结果
     */
    public int updateNetworkMap(NetworkMap networkMap);

    /**
     * 删除网络拓扑
     * 
     * @param id 网络拓扑主键
     * @return 结果
     */
    public int deleteNetworkMapById(Integer id);

    /**
     * 批量删除网络拓扑
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNetworkMapByIds(Integer[] ids);
}
